@@ -1,27 +1,30 @@
 import {expectType} from 'tsd';
-import boxen = require('.');
-import {Spacing, BorderStyle, CustomBorderStyle} from '.';
+import boxen, {type Spacing, type CustomBorderStyle} from './index.js';
 
 const border: CustomBorderStyle = {
 	topLeft: ' ',
 	topRight: ' ',
 	bottomLeft: ' ',
 	bottomRight: ' ',
-	horizontal: ' ',
-	vertical: ' '
+	top: ' ',
+	bottom: ' ',
+	left: ' ',
+	right: ' ',
 };
 
 const spacing: Spacing = {
 	top: 1,
 	right: 0,
 	bottom: 1,
-	left: 0
+	left: 0,
 };
 
 expectType<string>(boxen('unicorns'));
+expectType<string>(boxen('unicorns', {title: 'title'}));
+expectType<string>(boxen('unicorns', {title: 'title', titleAlignment: 'center'}));
 expectType<string>(boxen('unicorns', {borderColor: 'green'}));
 expectType<string>(boxen('unicorns', {borderColor: '#ff0000'}));
-expectType<string>(boxen('unicorns', {borderStyle: BorderStyle.Double}));
+expectType<string>(boxen('unicorns', {borderStyle: 'double'}));
 expectType<string>(boxen('unicorns', {borderStyle: border}));
 expectType<string>(boxen('unicorns', {dimBorder: true}));
 expectType<string>(boxen('unicorns', {padding: 3}));
@@ -31,4 +34,7 @@ expectType<string>(boxen('unicorns', {margin: spacing}));
 expectType<string>(boxen('unicorns', {float: 'center'}));
 expectType<string>(boxen('unicorns', {backgroundColor: 'green'}));
 expectType<string>(boxen('unicorns', {backgroundColor: '#ff0000'}));
-expectType<string>(boxen('unicorns', {align: 'right'}));
+expectType<string>(boxen('unicorns', {textAlignment: 'right'}));
+expectType<string>(boxen('unicorns', {width: 20}));
+expectType<string>(boxen('unicorns', {height: 5}));
+expectType<string>(boxen('unicorns', {fullscreen: true}));
